@@ -22,7 +22,7 @@ import dbus.service
 import dbus.mainloop.qt
 import pickle
 
-__version__ = '0.0.21'
+__version__ = '0.0.22'
 
 #Here is the installation of the hook. Each time a untrapped/unmanaged exception will
 #happen my_excepthook will be called.
@@ -548,6 +548,7 @@ class KhweetsView(QListView):
         QListView.__init__(self,parent)
         self.setIconSize(QSize(128, 128))
         self.setWordWrap(True)
+        self.setUniformItemSizes(True)
         self.setResizeMode(QListView.Adjust)
         self.setViewMode(QListView.ListMode)
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
@@ -664,57 +665,60 @@ class KhweeteurPref(QMainWindow):
             self.settings.setValue('twitter_access_token',False)
             self.twitter_value.setText('Auth on Twitter')
         else:
-            import os
-            import sys
-            try:
-                from urlparse import parse_qsl
-            except:
-                from cgi import parse_qsl
-            import oauth2 as oauth
-            
-            REQUEST_TOKEN_URL = 'https://api.twitter.com/oauth/request_token'
-            ACCESS_TOKEN_URL  = 'https://api.twitter.com/oauth/access_token'
-            AUTHORIZATION_URL = 'https://api.twitter.com/oauth/authorize'
-
-            signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
-            oauth_consumer             = oauth.Consumer(key=KHWEETEUR_TWITTER_CONSUMER_KEY, secret=KHWEETEUR_TWITTER_CONSUMER_SECRET)
-            oauth_client               = oauth.Client(oauth_consumer)
-            
-            resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET')
-            
-            if resp['status'] != '200':
-                KhweeteurNotification().warn('Invalid respond from Twitter requesting temp token: %s' % resp['status'])
+            if not self.parent.nw.device_has_networking:
+                self.parent.nw.request_connection_with_tmp_callback(self.request_twitter_access_or_clear)
             else:
-                request_token = dict(parse_qsl(content))
-
-                QDesktopServices.openUrl(QUrl('%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])))
+                import os
+                import sys
+                try:
+                    from urlparse import parse_qsl
+                except:
+                    from cgi import parse_qsl
+                import oauth2 as oauth
                 
-                pincode, ok = QInputDialog.getText(self, 'Twitter Authentification', 'Enter the pincode :')
-
-                if ok:
-                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
-                    token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
-                    token.set_verifier(str(pincode))
-
-                    oauth_client  = oauth.Client(oauth_consumer, token)
-                    resp, content = oauth_client.request(ACCESS_TOKEN_URL, method='POST', body='oauth_verifier=%s' % str(pincode))
-                    access_token  = dict(parse_qsl(content))
-
-                    if resp['status'] != '200':
-                        KhweeteurNotification().warn('The request for a Token did not succeed: %s' % resp['status'])
-                        self.settings.setValue('twitter_access_token_key',QString())
-                        self.settings.setValue('twitter_access_token_secret',QString())
-                        self.settings.setValue('twitter_access_token',False)
-                    else:
-                        print access_token['oauth_token']
-                        print access_token['oauth_token_secret']
-                        self.settings.setValue('twitter_access_token_key',QString(access_token['oauth_token']))
-                        self.settings.setValue('twitter_access_token_secret',QString(access_token['oauth_token_secret']))
-                        self.settings.setValue('twitter_access_token',True)
-                        self.twitter_value.setText('Clear Twitter Auth')
-                        KhweeteurNotification().info('Khweeteur is now authorized to connect')
-                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+                REQUEST_TOKEN_URL = 'https://api.twitter.com/oauth/request_token'
+                ACCESS_TOKEN_URL  = 'https://api.twitter.com/oauth/access_token'
+                AUTHORIZATION_URL = 'https://api.twitter.com/oauth/authorize'
+    
+                signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
+                oauth_consumer             = oauth.Consumer(key=KHWEETEUR_TWITTER_CONSUMER_KEY, secret=KHWEETEUR_TWITTER_CONSUMER_SECRET)
+                oauth_client               = oauth.Client(oauth_consumer)
                 
+                resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET')
+                
+                if resp['status'] != '200':
+                    KhweeteurNotification().warn('Invalid respond from Twitter requesting temp token: %s' % resp['status'])
+                else:
+                    request_token = dict(parse_qsl(content))
+    
+                    QDesktopServices.openUrl(QUrl('%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])))
+                    
+                    pincode, ok = QInputDialog.getText(self, 'Twitter Authentification', 'Enter the pincode :')
+    
+                    if ok:
+                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+                        token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
+                        token.set_verifier(str(pincode))
+    
+                        oauth_client  = oauth.Client(oauth_consumer, token)
+                        resp, content = oauth_client.request(ACCESS_TOKEN_URL, method='POST', body='oauth_verifier=%s' % str(pincode))
+                        access_token  = dict(parse_qsl(content))
+    
+                        if resp['status'] != '200':
+                            KhweeteurNotification().warn('The request for a Token did not succeed: %s' % resp['status'])
+                            self.settings.setValue('twitter_access_token_key',QString())
+                            self.settings.setValue('twitter_access_token_secret',QString())
+                            self.settings.setValue('twitter_access_token',False)
+                        else:
+                            print access_token['oauth_token']
+                            print access_token['oauth_token_secret']
+                            self.settings.setValue('twitter_access_token_key',QString(access_token['oauth_token']))
+                            self.settings.setValue('twitter_access_token_secret',QString(access_token['oauth_token_secret']))
+                            self.settings.setValue('twitter_access_token',True)
+                            self.twitter_value.setText('Clear Twitter Auth')
+                            KhweeteurNotification().info('Khweeteur is now authorized to connect')
+                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+                    
     def request_identica_access_or_clear(self):
 
         if self.settings.value('identica_access_token').toBool():
@@ -723,57 +727,60 @@ class KhweeteurPref(QMainWindow):
             self.settings.setValue('identica_access_token',False)
             self.identica_value.setText('Auth on Identi.ca')
         else:
-            import os
-            import sys
-            try:
-                from urlparse import parse_qsl
-            except:
-                from cgi import parse_qsl
-            import oauth2 as oauth
-            
-            REQUEST_TOKEN_URL = 'http://identi.ca/api/oauth/request_token'
-            ACCESS_TOKEN_URL  = 'http://identi.ca/api/oauth/access_token'
-            AUTHORIZATION_URL = 'http://identi.ca/api/oauth/authorize'
-
-            signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
-            oauth_consumer             = oauth.Consumer(key=KHWEETEUR_IDENTICA_CONSUMER_KEY, secret=KHWEETEUR_IDENTICA_CONSUMER_SECRET)
-            oauth_client               = oauth.Client(oauth_consumer)
-            
-            resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET')
-            
-            if resp['status'] != '200':
-                KhweeteurNotification().warn('Invalid respond from Identi.ca requesting temp token: %s' % resp['status'])
+            if not self.parent.nw.device_has_networking:
+                self.parent.nw.request_connection_with_tmp_callback(self.request_identica_access_or_clear)
             else:
-                request_token = dict(parse_qsl(content))
-
-                QDesktopServices.openUrl(QUrl('%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])))
+                import os
+                import sys
+                try:
+                    from urlparse import parse_qsl
+                except:
+                    from cgi import parse_qsl
+                import oauth2 as oauth
                 
-                pincode, ok = QInputDialog.getText(self, 'Identi.ca Authentification', 'Enter the token :')
-
-                if ok:
-                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
-                    token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
-                    token.set_verifier(str(pincode))
-
-                    oauth_client  = oauth.Client(oauth_consumer, token)
-                    resp, content = oauth_client.request(ACCESS_TOKEN_URL, method='POST', body='oauth_verifier=%s' % str(pincode))
-                    access_token  = dict(parse_qsl(content))
-
-                    if resp['status'] != '200':
-                        KhweeteurNotification().warn('The request for a Token did not succeed: %s' % resp['status'])
-                        self.settings.setValue('identica_access_token_key',QString())
-                        self.settings.setValue('identica_access_token_secret',QString())
-                        self.settings.setValue('identica_access_token',False)
-                    else:
-                        print access_token['oauth_token']
-                        print access_token['oauth_token_secret']
-                        self.settings.setValue('identica_access_token_key',QString(access_token['oauth_token']))
-                        self.settings.setValue('identica_access_token_secret',QString(access_token['oauth_token_secret']))
-                        self.settings.setValue('identica_access_token',True)
-                        self.identica_value.setText('Clear Identi.ca Auth')
-                        KhweeteurNotification().info('Khweeteur is now authorized to connect')
-                    self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+                REQUEST_TOKEN_URL = 'http://identi.ca/api/oauth/request_token'
+                ACCESS_TOKEN_URL  = 'http://identi.ca/api/oauth/access_token'
+                AUTHORIZATION_URL = 'http://identi.ca/api/oauth/authorize'
+    
+                signature_method_hmac_sha1 = oauth.SignatureMethod_HMAC_SHA1()
+                oauth_consumer             = oauth.Consumer(key=KHWEETEUR_IDENTICA_CONSUMER_KEY, secret=KHWEETEUR_IDENTICA_CONSUMER_SECRET)
+                oauth_client               = oauth.Client(oauth_consumer)
+                
+                resp, content = oauth_client.request(REQUEST_TOKEN_URL, 'GET')
+                
+                if resp['status'] != '200':
+                    KhweeteurNotification().warn('Invalid respond from Identi.ca requesting temp token: %s' % resp['status'])
+                else:
+                    request_token = dict(parse_qsl(content))
+    
+                    QDesktopServices.openUrl(QUrl('%s?oauth_token=%s' % (AUTHORIZATION_URL, request_token['oauth_token'])))
                     
+                    pincode, ok = QInputDialog.getText(self, 'Identi.ca Authentification', 'Enter the token :')
+    
+                    if ok:
+                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
+                        token = oauth.Token(request_token['oauth_token'], request_token['oauth_token_secret'])
+                        token.set_verifier(str(pincode))
+    
+                        oauth_client  = oauth.Client(oauth_consumer, token)
+                        resp, content = oauth_client.request(ACCESS_TOKEN_URL, method='POST', body='oauth_verifier=%s' % str(pincode))
+                        access_token  = dict(parse_qsl(content))
+    
+                        if resp['status'] != '200':
+                            KhweeteurNotification().warn('The request for a Token did not succeed: %s' % resp['status'])
+                            self.settings.setValue('identica_access_token_key',QString())
+                            self.settings.setValue('identica_access_token_secret',QString())
+                            self.settings.setValue('identica_access_token',False)
+                        else:
+                            print access_token['oauth_token']
+                            print access_token['oauth_token_secret']
+                            self.settings.setValue('identica_access_token_key',QString(access_token['oauth_token']))
+                            self.settings.setValue('identica_access_token_secret',QString(access_token['oauth_token_secret']))
+                            self.settings.setValue('identica_access_token',True)
+                            self.identica_value.setText('Clear Identi.ca Auth')
+                            KhweeteurNotification().info('Khweeteur is now authorized to connect')
+                        self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,False)
+                        
     def setupGUI(self):
 #        self.aWidget = QWidget()
         self.scrollArea = QScrollArea(self)
@@ -955,88 +962,94 @@ class KhweeteurWin(QMainWindow):
             except StandardError,e:
                 print e
                 
-    def follow(self):
+    def follow(self):       
         self.tweetActionDialog.accept()
-        for index in self.tweetsView.selectedIndexes():
-            if ((QMessageBox.question(self,
-                       "Khweeteur",
-                       "Follow : %s ?" % self.tweetsModel._items[index.row()][2],
-                       QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
-                user_screenname = self.tweetsModel._items[index.row()][2]
-                print 'DEBUG Follow:',user_screenname
-                try:
-                    if self.settings.value("twitter_access_token_key").toString()!='':     
-                        api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                          access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
-                                          access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
-                        api.SetUserAgent('Khweeteur/%s' % (__version__))
-                        api.CreateFriendship(user_screenname)
-                        self.notifications.info('You are now following %s on Twitter' % (user_screenname))
-                except (twitter.TwitterError,StandardError),e:
-                    if type(e)==twitter.TwitterError:
-                        self.notifications.warn('Add %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
-                        print e.message
-                    else:
-                        self.notifications.warn('Add %s to friendship failed on Twitter : %s' %(user_screenname,str(e)))
-                        print e                     
-                try:
-                    if self.settings.value("identica_access_token_key").toString()!='': 
-                        api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
-                                          password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                          access_token_key=str(self.settings.value("identica_access_token_key").toString()),
-                                          access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
-                        api.SetUserAgent('Khweeteur/%s' % (__version__))    
-                        api.CreateFriendship(user_screenname)
-                        self.notifications.info('You are now following %s on Identi.ca' % (user_screenname))
-                except (twitter.TwitterError,StandardError),e:
-                    if type(e)==twitter.TwitterError:
-                        self.notifications.warn('Add %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
-                        print e.message
-                    else:
-                        self.notifications.warn('Add %s to friendship failed on Identi.ca : %s' %(user_screenname,str(e)))
-                        print e                                   
+        if not self.nw.device_has_networking:
+            self.parent().nw.request_connection_with_tmp_callback(self.follow)
+        else:
+            for index in self.tweetsView.selectedIndexes():
+                if ((QMessageBox.question(self,
+                           "Khweeteur",
+                           "Follow : %s ?" % self.tweetsModel._items[index.row()][2],
+                           QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
+                    user_screenname = self.tweetsModel._items[index.row()][2]
+                    print 'DEBUG Follow:',user_screenname
+                    try:
+                        if self.settings.value("twitter_access_token_key").toString()!='':     
+                            api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
+                                              access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+                                              access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+                            api.SetUserAgent('Khweeteur/%s' % (__version__))
+                            api.CreateFriendship(user_screenname)
+                            self.notifications.info('You are now following %s on Twitter' % (user_screenname))
+                    except (twitter.TwitterError,StandardError),e:
+                        if type(e)==twitter.TwitterError:
+                            self.notifications.warn('Add %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
+                            print e.message
+                        else:
+                            self.notifications.warn('Add %s to friendship failed on Twitter : %s' %(user_screenname,str(e)))
+                            print e                     
+                    try:
+                        if self.settings.value("identica_access_token_key").toString()!='': 
+                            api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
+                                              password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
+                                              access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+                                              access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
+                            api.SetUserAgent('Khweeteur/%s' % (__version__))    
+                            api.CreateFriendship(user_screenname)
+                            self.notifications.info('You are now following %s on Identi.ca' % (user_screenname))
+                    except (twitter.TwitterError,StandardError),e:
+                        if type(e)==twitter.TwitterError:
+                            self.notifications.warn('Add %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
+                            print e.message
+                        else:
+                            self.notifications.warn('Add %s to friendship failed on Identi.ca : %s' %(user_screenname,str(e)))
+                            print e                                   
 
     def unfollow(self):  
         self.tweetActionDialog.accept()
-        for index in self.tweetsView.selectedIndexes():
-            if ((QMessageBox.question(self,
-                       "Khweeteur",
-                       "Follow : %s ?" % self.tweetsModel._items[index.row()][2],
-                       QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
-                user_screenname = self.tweetsModel._items[index.row()][2]
-                print 'DEBUG Follow:',user_screenname
-                try:
-                    if self.settings.value("twitter_access_token_key").toString()!='':     
-                        api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                          access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
-                                          access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
-                        api.SetUserAgent('Khweeteur/%s' % (__version__))
-                        api.DestroyFriendship(user_screenname)
-                        self.notifications.info('You didn\'t follow %s anymore on Twitter' % (user_screenname))
-                except (twitter.TwitterError,StandardError),e:
-                    if type(e)==twitter.TwitterError:
-                        self.notifications.warn('Remove %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
-                        print e.message
-                    else:
-                        self.notifications.warn('Remove %s to friendship failed on Twitter : %s' %(user_screenname,str(e)))
-                        print e                     
-                try:
-                    if self.settings.value("identica_access_token_key").toString()!='': 
-                        api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
-                                          password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                          access_token_key=str(self.settings.value("identica_access_token_key").toString()),
-                                          access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
-                        api.SetUserAgent('Khweeteur/%s' % (__version__))    
-                        api.DestroyFriendship(user_screenname)
-                        self.notifications.info('You didn\'t follow %s anymore on Identi.ca' % (user_screenname))
-                except (twitter.TwitterError,StandardError),e:
-                    if type(e)==twitter.TwitterError:
-                        self.notifications.warn('Remove %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
-                        print e.message
-                    else:
-                        self.notifications.warn('Remove %s to friendship failed on Identi.ca : %s' %(user_screenname,str(e)))
-                        print e                           
-                        
+        if not self.nw.device_has_networking:
+            self.parent().nw.request_connection_with_tmp_callback(self.unfollow)
+        else:
+            for index in self.tweetsView.selectedIndexes():
+                if ((QMessageBox.question(self,
+                           "Khweeteur",
+                           "Follow : %s ?" % self.tweetsModel._items[index.row()][2],
+                           QMessageBox.Yes|QMessageBox.Close)) == QMessageBox.Yes):
+                    user_screenname = self.tweetsModel._items[index.row()][2]
+                    print 'DEBUG Follow:',user_screenname
+                    try:
+                        if self.settings.value("twitter_access_token_key").toString()!='':     
+                            api = twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
+                                              access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+                                              access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+                            api.SetUserAgent('Khweeteur/%s' % (__version__))
+                            api.DestroyFriendship(user_screenname)
+                            self.notifications.info('You didn\'t follow %s anymore on Twitter' % (user_screenname))
+                    except (twitter.TwitterError,StandardError),e:
+                        if type(e)==twitter.TwitterError:
+                            self.notifications.warn('Remove %s to friendship failed on Twitter : %s' %(user_screenname,e.message))
+                            print e.message
+                        else:
+                            self.notifications.warn('Remove %s to friendship failed on Twitter : %s' %(user_screenname,str(e)))
+                            print e                     
+                    try:
+                        if self.settings.value("identica_access_token_key").toString()!='': 
+                            api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
+                                              password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
+                                              access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+                                              access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))    
+                            api.SetUserAgent('Khweeteur/%s' % (__version__))    
+                            api.DestroyFriendship(user_screenname)
+                            self.notifications.info('You didn\'t follow %s anymore on Identi.ca' % (user_screenname))
+                    except (twitter.TwitterError,StandardError),e:
+                        if type(e)==twitter.TwitterError:
+                            self.notifications.warn('Remove %s to friendship failed on Identi.ca : %s' %(user_screenname,e.message))
+                            print e.message
+                        else:
+                            self.notifications.warn('Remove %s to friendship failed on Identi.ca : %s' %(user_screenname,str(e)))
+                            print e                           
+                            
     def retweet(self):
         self.tweetActionDialog.accept()
         for index in self.tweetsView.selectedIndexes():
@@ -1089,14 +1102,17 @@ class KhweeteurWin(QMainWindow):
 #Test of a threaded post from #Khweeteur 0.0.21
 
     def tweet(self):
-        self.tb_text.setDisabled(True)
-        self.tb_tweet.setDisabled(True)
-        self.tweetAction = KhweeteurActionWorker(self,'tweet',unicode(self.tb_text.text()).encode('UTF-8'),self.tb_text_replyid,self.tb_text_replytext)
-        self.connect(self.tweetAction, SIGNAL("tweetSent()"), self.tweetSent)
-        self.connect(self.tweetAction, SIGNAL("finished()"), self.tweetSentFinished)
-        self.notifications.connect(self.tweetAction, SIGNAL('info(PyQt_PyObject)'), self.notifications.info)
-        self.notifications.connect(self.tweetAction, SIGNAL('warn(PyQt_PyObject)'), self.notifications.warn)
-        self.tweetAction.start()
+        if not self.nw.device_has_networking:
+            self.nw.request_connection_with_tmp_callback(self.tweet)
+        else:
+            self.tb_text.setDisabled(True)
+            self.tb_tweet.setDisabled(True)
+            self.tweetAction = KhweeteurActionWorker(self,'tweet',unicode(self.tb_text.text()).encode('UTF-8'),self.tb_text_replyid,self.tb_text_replytext)
+            self.connect(self.tweetAction, SIGNAL("tweetSent()"), self.tweetSent)
+            self.connect(self.tweetAction, SIGNAL("finished()"), self.tweetSentFinished)
+            self.notifications.connect(self.tweetAction, SIGNAL('info(PyQt_PyObject)'), self.notifications.info)
+            self.notifications.connect(self.tweetAction, SIGNAL('warn(PyQt_PyObject)'), self.notifications.warn)
+            self.tweetAction.start()
 
 #        try:
 #                status_text = unicode(self.tb_text.text()).encode('UTF-8')
